extern const char **_dictionary_suse;
#ifndef DICTIONARY_REQUEST
	#define DICTIONARY_REQUEST \
	const char **_dictionary_suse;\
	TRANSLATE_SYSTEM_REQ _dictionary_req_suse("suse",_dictionary_suse,7,0);\
	void dummy_dict_suse(){}
#endif
#ifndef MSG_U
	#define MSG_U(id,m)	_dictionary_suse[id]
	#define MSG_B(id,m,n)	_dictionary_suse[id]
	#define MSG_R(id)	_dictionary_suse[id]
	#define P_MSG_U(id,m)	new_trans_notload(_dictionary_suse,id)
	#define P_MSG_B(id,m,n)	new_trans_notload(_dictionary_suse,id)
	#define P_MSG_R(id)	new_trans_notload(_dictionary_suse,id)
#endif
#define T_USAGE	0
#define T_AUTHENTICATE	1
#define I_AUTHREQ	2
#define T_NEWPASS	3
#define I_NEWPASS	4
#define I_DISABLED	5
#define I_ENABLED	6
